DiskCapacity class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFreeDiskSpace(
) → Future< double> - Returns the total free space in megaoctets (Mo) available on the device.
-
getFreeDiskSpaceForPath(
String path) → Future< double> - Returns the free space in megaoctets (Mo) available for a specific path.
-
getTotalDiskSpace(
) → Future< double> - Returns the total disk space in megaoctets (Mo) on the device.
-
getTotalDiskSpaceForPath(
String path) → Future< double> - Returns the total space in megaoctets (Mo) available for a specific path.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited